require 'spec_helper'
feature 'Traveler Management', js: true do
  let(:traveler_attrs) { attributes_for :traveler }
  let(:new_traveler) { build :traveler }
  let(:existing_traveler) { create :traveler }

  feature 'Adding travelers' do
    def complete_the_form(attrs=nil)
      attrs ||= traveler_attrs
      form_selector = if current_path =~ /edit$/ then 'form.edit_traveler'
                      else 'form.new_traveler' end
      within form_selector do
        fill_in 'Name', with: attrs[:name]
        yield(attrs) if block_given?
        click_button ' Traveler'
      end
    end
    def expect_success
      expect(page).to have_content 'Traveler was successfully '
    end

    it 'basically works' do
      visit new_traveler_path
      expect {
        complete_the_form
        expect_success
      }.to change { Traveler.count }.by 1
      t = Traveler.last
      expect(t.current_location.id).to be_nil
      expect(t.location_history.any?).to be false
    end

    it 'adds a current location when a zip code is supplied' do
      visit new_traveler_path
      expect {
        complete_the_form {
          fill_in 'traveler_current_location_attributes_zip', with: rand(10000..99999).to_s
          sleep 1 }
        expect_success
      }.to change { Traveler.count }.by 1
      t = Traveler.last
      expect(t.current_location.id).not_to be_nil
      expect(t.location_history.any?).to be false
    end

    it 'moves old current_location to location history when new one added' do
      visit new_traveler_path
      expect {
        complete_the_form {
          fill_in 'traveler_current_location_attributes_zip', with: rand(10000..99999).to_s
          sleep 1 }
        expect_success
      }.to change { Traveler.count }.by 1
      t = Traveler.last
      expect(t.current_location.id).not_to be_nil
      expect(t.location_history.count).to eq 0
      visit edit_traveler_path(t)
      expect {
        complete_the_form {
          fill_in 'traveler_current_location_attributes_zip', with: rand(10000..99999).to_s
          sleep 1 }
        expect_success
      }.to change { t.reload.current_location.zip }
      expect(t.location_history.count).to eq 1
    end

  end
end
