require 'spec_helper'

describe Traveler do
  let(:new_traveler) { build :traveler }
  let(:traveler_with_location) { create :traveler, :with_current_location }
  let(:traveler_with_history) { create :traveler, :with_location_history }

  it 'has a valid factory' do
    expect(new_traveler).to be_valid
    %i(current_location location_history).each{|trait|
      expect(build(:traveler, :"with_#{trait}")).to be_valid }
  end

  it 'sets the current location when provided with attributes for it' do
    expect(traveler_with_location.current_location.id).not_to be_nil
  end
  it 'sets location history when provided with attributes for it' do
    expect(traveler_with_history.current_location.id).not_to be_nil
    expect(traveler_with_history.location_history.any?).to be true
  end

  it 'moves old traveler locations into the history association' do
    expect(traveler_with_location.location_history.count).to eq 0
    expect {
      traveler_with_location.current_location.zip = rand(10000..99999).to_s
      traveler_with_location.save
    }.to change { traveler_with_location.reload.location_history.count }.by 1
    expect( traveler_with_location.current_location.id ).not_to be_nil
    expect( traveler_with_location.location_history.any?).to be true
    expect( traveler_with_location.location_history ).not_to include(
            traveler_with_location.current_location )
  end

  it 'to_sentence returns "Location unavailable" if location_blank? is true' do
    expect(new_traveler.current_location.to_sentence).to eq 'Location unavailable'
  end

  it 'gets address components from street_address' do
    expect {
      new_traveler.current_location.street_address = '4910 E Warren Ave'
      new_traveler.save
    }.to change { new_traveler.current_location.latitude }
  end

end
